searchData={"items":[{"type":"module","title":"XDGBasedir","doc":"Helpers for using directories per the [XDG Base Directory Specification](https://specifications.freedesktop.org/basedir-spec/0.8/) version 0.8.","ref":"XDGBasedir.html"},{"type":"module","title":"Examples - XDGBasedir","doc":"iex> System.put_env(\"HOME\", \"/home/user\")\n    :ok\n    iex> System.delete_env(\"XDG_CONFIG_HOME\")\n    :ok\n    iex> XDGBasedir.user_config_dir\n    \"/home/user/.config\"\n    iex> XDGBasedir.user_config_dir(\"my_app\")\n    \"/home/user/.config/my_app\"\n    iex> System.put_env(\"XDG_STATE_HOME\", \"/my/state/path\")\n    :ok\n    iex> XDGBasedir.user_state_dir(\"my_app\")\n    \"/my/state/path/my_app\"","ref":"XDGBasedir.html#module-examples"},{"type":"function","title":"XDGBasedir.config_dirs/0","doc":"Gets the list of config directories to search after the user config base directory,\nwhich is either parsed from the value of `$XDG_CONFIG_DIRS` or the default of `[\"/etc/xdg\"]`.","ref":"XDGBasedir.html#config_dirs/0"},{"type":"function","title":"Examples - XDGBasedir.config_dirs/0","doc":"iex> System.delete_env(\"XDG_CONFIG_DIRS\")\n    :ok\n    iex> XDGBasedir.config_dirs\n    [\"/etc/xdg\"]\n    iex> System.put_env(\"XDG_CONFIG_DIRS\", \"/cfg/1:/cfg/2\")\n    :ok\n    iex> XDGBasedir.config_dirs\n    [\"/cfg/1\", \"/cfg/2\"]","ref":"XDGBasedir.html#config_dirs/0-examples"},{"type":"function","title":"XDGBasedir.config_dirs/1","doc":"Joins a provided relative path to each directory in the list of config directories.","ref":"XDGBasedir.html#config_dirs/1"},{"type":"function","title":"Examples - XDGBasedir.config_dirs/1","doc":"iex> System.put_env(\"XDG_CONFIG_DIRS\", \"/cfg/1:/cfg/2\")\n    :ok\n    iex> XDGBasedir.config_dirs(\"my_app\")\n    [\"/cfg/1/my_app\", \"/cfg/2/my_app\"]","ref":"XDGBasedir.html#config_dirs/1-examples"},{"type":"function","title":"XDGBasedir.data_dirs/0","doc":"Gets the list of data directories to search after the user data base directory,\nwhich is either parsed from the value of `$XDG_DATA_DIRS` or the default of `[\"/usr/local/share\", \"/usr/share\"]`.","ref":"XDGBasedir.html#data_dirs/0"},{"type":"function","title":"Examples - XDGBasedir.data_dirs/0","doc":"iex> System.delete_env(\"XDG_DATA_DIRS\")\n    :ok\n    iex> XDGBasedir.data_dirs\n    [\"/usr/local/share\", \"/usr/share\"]\n    iex> System.put_env(\"XDG_DATA_DIRS\", \"/data/1:/data/2\")\n    :ok\n    iex> XDGBasedir.data_dirs\n    [\"/data/1\", \"/data/2\"]","ref":"XDGBasedir.html#data_dirs/0-examples"},{"type":"function","title":"XDGBasedir.data_dirs/1","doc":"Joins a provided relative path to each directory in the list of data directories.","ref":"XDGBasedir.html#data_dirs/1"},{"type":"function","title":"Examples - XDGBasedir.data_dirs/1","doc":"iex> System.put_env(\"XDG_DATA_DIRS\", \"/data/1:/data/2\")\n    :ok\n    iex> XDGBasedir.data_dirs(\"my_app\")\n    [\"/data/1/my_app\", \"/data/2/my_app\"]","ref":"XDGBasedir.html#data_dirs/1-examples"},{"type":"function","title":"XDGBasedir.user_bin_dir/0","doc":"Gets the user executable base directory, which is `$HOME/.local/bin` always per the spec.","ref":"XDGBasedir.html#user_bin_dir/0"},{"type":"function","title":"Examples - XDGBasedir.user_bin_dir/0","doc":"iex> System.put_env(\"HOME\", \"/home/user\")\n    :ok\n    iex> XDGBasedir.user_bin_dir\n    \"/home/user/.local/bin\"","ref":"XDGBasedir.html#user_bin_dir/0-examples"},{"type":"function","title":"XDGBasedir.user_cache_dir/0","doc":"Gets the user cache base directory, which is either the value of `$XDG_CACHE_HOME` or the default of `$HOME/.cache`.","ref":"XDGBasedir.html#user_cache_dir/0"},{"type":"function","title":"Examples - XDGBasedir.user_cache_dir/0","doc":"iex> System.put_env(\"HOME\", \"/home/user\")\n    :ok\n    iex> System.delete_env(\"XDG_CACHE_HOME\")\n    :ok\n    iex> XDGBasedir.user_cache_dir\n    \"/home/user/.cache\"\n    iex> System.put_env(\"XDG_CACHE_HOME\", \"/my/cache/path\")\n    :ok\n    iex> XDGBasedir.user_cache_dir\n    \"/my/cache/path\"","ref":"XDGBasedir.html#user_cache_dir/0-examples"},{"type":"function","title":"XDGBasedir.user_cache_dir/1","doc":"Joins a provided relative path to the user cache base directory.","ref":"XDGBasedir.html#user_cache_dir/1"},{"type":"function","title":"Examples - XDGBasedir.user_cache_dir/1","doc":"iex> System.put_env(\"XDG_CACHE_HOME\", \"/my/cache/path\")\n    :ok\n    iex> XDGBasedir.user_cache_dir(\"my_app\")\n    \"/my/cache/path/my_app\"","ref":"XDGBasedir.html#user_cache_dir/1-examples"},{"type":"function","title":"XDGBasedir.user_config_dir/0","doc":"Gets the user configuration base directory, which is either the value of `$XDG_CONFIG_HOME` or the default of `$HOME/.config`.","ref":"XDGBasedir.html#user_config_dir/0"},{"type":"function","title":"Examples - XDGBasedir.user_config_dir/0","doc":"iex> System.put_env(\"HOME\", \"/home/user\")\n    :ok\n    iex> System.delete_env(\"XDG_CONFIG_HOME\")\n    :ok\n    iex> XDGBasedir.user_config_dir\n    \"/home/user/.config\"\n    iex> System.put_env(\"XDG_CONFIG_HOME\", \"/my/config/path\")\n    :ok\n    iex> XDGBasedir.user_config_dir\n    \"/my/config/path\"","ref":"XDGBasedir.html#user_config_dir/0-examples"},{"type":"function","title":"XDGBasedir.user_config_dir/1","doc":"Joins a provided relative path to the user config base directory.","ref":"XDGBasedir.html#user_config_dir/1"},{"type":"function","title":"Examples - XDGBasedir.user_config_dir/1","doc":"iex> System.put_env(\"XDG_CONFIG_HOME\", \"/my/config/path\")\n    :ok\n    iex> XDGBasedir.user_config_dir(\"my_app\")\n    \"/my/config/path/my_app\"","ref":"XDGBasedir.html#user_config_dir/1-examples"},{"type":"function","title":"XDGBasedir.user_data_dir/0","doc":"Gets the user data base directory, which is either the value of `$XDG_DATA_HOME` or the default of `$HOME/.local/share`.","ref":"XDGBasedir.html#user_data_dir/0"},{"type":"function","title":"Examples - XDGBasedir.user_data_dir/0","doc":"iex> System.put_env(\"HOME\", \"/home/user\")\n    :ok\n    iex> System.delete_env(\"XDG_DATA_HOME\")\n    :ok\n    iex> XDGBasedir.user_data_dir\n    \"/home/user/.local/share\"\n    iex> System.put_env(\"XDG_DATA_HOME\", \"/my/data/path\")\n    :ok\n    iex> XDGBasedir.user_data_dir\n    \"/my/data/path\"","ref":"XDGBasedir.html#user_data_dir/0-examples"},{"type":"function","title":"XDGBasedir.user_data_dir/1","doc":"Joins a provided relative path to the user data base directory.","ref":"XDGBasedir.html#user_data_dir/1"},{"type":"function","title":"Examples - XDGBasedir.user_data_dir/1","doc":"iex> System.put_env(\"XDG_DATA_HOME\", \"/my/data/path\")\n    :ok\n    iex> XDGBasedir.user_data_dir(\"my_app\")\n    \"/my/data/path/my_app\"","ref":"XDGBasedir.html#user_data_dir/1-examples"},{"type":"function","title":"XDGBasedir.user_runtime_dir/0","doc":"Gets the user runtime base directory if it is set, which is the value of `$XDG_RUNTIME_DIR`.\n\nBecause the specification does not provide a default runtime base directory, returns nil if `$XDG_RUNTIME_DIR` is not set.","ref":"XDGBasedir.html#user_runtime_dir/0"},{"type":"function","title":"Examples - XDGBasedir.user_runtime_dir/0","doc":"iex> System.delete_env(\"XDG_RUNTIME_DIR\")\n    :ok\n    iex> XDGBasedir.user_runtime_dir\n    nil\n    iex> System.put_env(\"XDG_RUNTIME_DIR\", \"/my/runtime/path\")\n    :ok\n    iex> XDGBasedir.user_runtime_dir\n    \"/my/runtime/path\"","ref":"XDGBasedir.html#user_runtime_dir/0-examples"},{"type":"function","title":"XDGBasedir.user_runtime_dir/1","doc":"Joins a provided relative path to the user runtime base directory if it is set.\n\nBecause the specification does not provide a default runtime base directory, returns nil if `$XDG_RUNTIME_DIR` is not set.","ref":"XDGBasedir.html#user_runtime_dir/1"},{"type":"function","title":"Examples - XDGBasedir.user_runtime_dir/1","doc":"iex> System.put_env(\"XDG_RUNTIME_DIR\", \"/my/runtime/path\")\n    :ok\n    iex> XDGBasedir.user_runtime_dir(\"my_app\")\n    \"/my/runtime/path/my_app\"","ref":"XDGBasedir.html#user_runtime_dir/1-examples"},{"type":"function","title":"XDGBasedir.user_state_dir/0","doc":"Gets the user state base directory, which is either the value of `$XDG_STATE_HOME` or the default of `$HOME/.local/state`.","ref":"XDGBasedir.html#user_state_dir/0"},{"type":"function","title":"Examples - XDGBasedir.user_state_dir/0","doc":"iex> System.put_env(\"HOME\", \"/home/user\")\n    :ok\n    iex> System.delete_env(\"XDG_STATE_HOME\")\n    :ok\n    iex> XDGBasedir.user_state_dir\n    \"/home/user/.local/state\"\n    iex> System.put_env(\"XDG_STATE_HOME\", \"/my/state/path\")\n    :ok\n    iex> XDGBasedir.user_state_dir\n    \"/my/state/path\"","ref":"XDGBasedir.html#user_state_dir/0-examples"},{"type":"function","title":"XDGBasedir.user_state_dir/1","doc":"Joins a provided relative path to the user state base directory.","ref":"XDGBasedir.html#user_state_dir/1"},{"type":"function","title":"Examples - XDGBasedir.user_state_dir/1","doc":"iex> System.put_env(\"XDG_STATE_HOME\", \"/my/state/path\")\n    :ok\n    iex> XDGBasedir.user_state_dir(\"my_app\")\n    \"/my/state/path/my_app\"","ref":"XDGBasedir.html#user_state_dir/1-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}